package com.opticon.scantest;

import androidx.appcompat.app.AppCompatActivity;

import android.annotation.SuppressLint;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import com.opticon.scannersdk.scanner.BarcodeEventListener;
import com.opticon.scannersdk.scanner.ReadData;
import com.opticon.scannersdk.scanner.ReadDataExtra;
import com.opticon.scannersdk.scanner.Scanner;
import com.opticon.scannersdk.scanner.ScannerInfo;
import com.opticon.scannersdk.scanner.ScannerManager;
import com.opticon.scannersdk.scanner.ScannerType;
import com.opticon.scannersdk.scanner.softwarescanner.BroadcastToScannerService;
import com.opticon.scannerservice.IScannerService;
import com.opticon.scannerservice.IScannerServiceCallback;
import com.opticon.settings.ScannerSettings;
import com.opticon.settings.readoption.ReadOption;

public class MainActivity extends AppCompatActivity implements BarcodeEventListener {

    Button scan;
    TextView barcode;
    ScannerManager scannerManager;
    Scanner scanner;
    boolean isScanning;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        scan = (Button) findViewById(R.id.button_scan);
        barcode = (TextView) findViewById(R.id.textView1);
        scannerManager = ScannerManager.getInstance(this);
        for (ScannerInfo info : scannerManager.getScannerInfoList()) {
            if (info.getType() == ScannerType.SOFTWARE_SCANNER) {
                scanner = scannerManager.getScanner(info);
                break;
            }
        }
        scan.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                if (!scanner.isConnected())
                    return true;
                if (event.getAction() == MotionEvent.ACTION_DOWN)
                    scanner.startScan();
                else if (event.getAction() == MotionEvent.ACTION_UP)
                    scanner.stopScan();
                return true;
            }
        });
    }


    @Override
    protected void onResume() {
        super.onResume();
        if (scanner != null) {
            scanner.addBarcodeEventListener(this);
            scanner.init();
        }
    }

    @Override
    protected void onPause() {
        super.onPause();
        if(scanner != null){
            scanner.deinit();
            scanner.removeBarcodeEventListener();
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if(scanner != null){
            scanner.deinit();
            if(scanner.isConnected())
                scanner.removeBarcodeEventListener();
        }
    }

    @Override
    public void onReadData(ReadData readData) {
        barcode.setText(readData.getText());
    }

    @Override
    public void onTimeout()  {
        barcode.setText("Timeout");
    }
}