package com.example.scannersdksample

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.graphics.Bitmap
import android.os.Build
import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.opticon.scannersdk.scanner.*
import com.opticon.settings.readoption.ReadOption

class MainActivity : AppCompatActivity(), BarcodeEventListener {
    val TAG = "ScannerSdkSample"
    var scanner: Scanner? = null
    var scannerManager: ScannerManager? = null
    var isScanning: Boolean = false

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        setButtonOnClickListener()

        Log.d("name", Build.MODEL)

        scannerManager = ScannerManager.getInstance(this)
        for (info in scannerManager!!.scannerInfoList) {
            //ソフトウェアスキャナ(端末内臓スキャナ)を操作したいとき
            if (info.type == ScannerType.SOFTWARE_SCANNER) {
                scanner = scannerManager!!.getScanner(info)
                break
            }
        }


    }

    override fun onResume() {
        super.onResume()
        if (scanner != null) {
            scanner!!.addBarcodeEventListener(this)
            Log.d(TAG, "" + scanner!!.init())
        }
        setReceiver()
    }

    override fun onPause() {
        super.onPause()
        super.onPause()
        if (scanner != null) {
            scanner!!.deinit()
            scanner!!.removeBarcodeEventListener()
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        if (scanner != null) {
            scanner!!.deinit()
            if (scanner!!.isConnected) scanner!!.removeBarcodeEventListener()
        }
    }

    //BarcodeEventListener
    override fun onReadData(readData: ReadData) {
        //読み取りデータを取得した際に呼ばれます
        Log.d(TAG, "onReadData:" + readData.text)
        Log.d(TAG, "onReadData:length:" + readData.rawData.size)
        Log.d(TAG, "onReadData:codeId:" + readData.codeID)

        val data = readData.text
        val textView = findViewById<TextView>(R.id.textViewReadData)
        textView.text = data
    }

    override fun onTimeout() {
        //読み取りを開始し、バーコードを読み取らずに時間が経過した際に呼ばれます
        Log.d(TAG, "onTimeout")
    }

    override fun onDecodeStart() {
        //読み取り開始時に呼ばれます
        isScanning = true
        Log.d(TAG, "onDecodeStart")
    }

    override fun onDecodeStop() {
        //読み取りの可否にかかわらず、読み取り終了時に呼ばれます
        isScanning = false
        Log.d(TAG, "onDecodeStop")
    }

    override fun onConnect() {
        //スキャナとの接続が開始された際に呼ばれます
        Log.d(TAG, "onConnect")
        changeIntentSettings()
    }

    override fun onDisconnect() {
        //スキャナとの接続が終了した際に呼ばれます
        Log.d(TAG, "onDisconnect")
    }

    override fun onImageData(bitmap: Bitmap?, byteArray: ByteArray?, i: Int) {
        //スキャナから画像を取得した際に呼ばれます
        Log.d(TAG, "onImageData")
        val imageView = findViewById<ImageView>(R.id.imageView)
        imageView.setImageBitmap(bitmap)
    }

    private fun setButtonOnClickListener() {
        findViewById<View>(R.id.buttonScan).setOnClickListener(onClickListenerScan())
        findViewById<View>(R.id.buttonSetting).setOnClickListener(onClickListenerSetting())
        findViewById<View>(R.id.buttonTakePicture).setOnClickListener(onClickListenerTakePicture())
    }

    private fun onClickListenerScan(): View.OnClickListener {
        return View.OnClickListener {
            if (!scanner!!.isConnected) return@OnClickListener
            if (isScanning) {
                scanner!!.stopScan()
            } else {
                scanner!!.startScan()
            }
        }
    }

    private fun onClickListenerSetting(): View.OnClickListener {
        return View.OnClickListener {
            if (!scanner!!.isConnected) return@OnClickListener
            val settings = scanner!!.settings
            if (settings != null) {
                if (settings.readOption.cameraIllumination == ReadOption.CameraIllumination.TURN_OFF) {
                    settings.readOption.cameraIllumination = ReadOption.CameraIllumination.TURN_ON
                } else {
                    settings.readOption.cameraIllumination = ReadOption.CameraIllumination.TURN_OFF
                }
            }
            scanner!!.settings = settings
        }
    }

    private fun onClickListenerTakePicture(): View.OnClickListener {
        return View.OnClickListener {
            if (!scanner!!.isConnected) return@OnClickListener
            scanner!!.takePicture(1)
        }
    }



    //intent sample
    private var receiver: MyReceiver? = null
    private fun setReceiver() {
        val filter = IntentFilter("com.opticon.decode.action")
        filter.addCategory("com.opticon.decode.category")
        receiver = object : MainActivity.MyReceiver() {
            override fun onReceive(context: Context, intent: Intent) {
                Log.e("receive intent", intent.toString())
                Log.e(
                        "receive intent",
                        "barcode type:" + intent.getStringExtra("com.opticon.decode.barcode_type")
                )
                Log.e(
                        "receive intent",
                        "barcode data:" + intent.getStringExtra("com.opticon.decode.barcode_data")
                )
            }
        }
        registerReceiver(receiver, filter)
    }

    private fun changeIntentSettings() {
        val settings = scanner!!.settings
        if (settings != null) {
            settings.softwareScanner.h35.wedge.intentIsEnable = true
            settings.softwareScanner.h35.wedge.intentAction = "com.opticon.decode.action"
            settings.softwareScanner.h35.wedge.intentCategory = "com.opticon.decode.category"
            settings.softwareScanner.h35.wedge.intentBarcodeType = "com.opticon.decode.barcode_type"
            settings.softwareScanner.h35.wedge.intentBarcodeData = "com.opticon.decode.barcode_data"
            settings.softwareScanner.h35.wedge.intentPackageName = "com.example.scannersdksample"
            scanner!!.settings = settings
        }
    }

    open class MyReceiver : BroadcastReceiver() {
        override fun onReceive(context: Context, intent: Intent) {}
    }
}